@@ -144,6 +144,23 @@ class Pubsub(object):
     def get_subscription_count(cls, event):
         return len(cls.__subscriptions.get(event, {}))
 
+    @classmethod
+    def get_subscription(cls, connection, event, key=None):
+        '''Return subscription object for given connection and event'''
+        session = ConnectionRegistry.get_session(connection)
+        if session == None:
+            raise custom_exceptions.PubsubException("No session found")
+
+        if key == None:    
+            sub = [ sub for sub in session.get('subscriptions', {}).values() if sub.event == event ]
+            try:
+                return sub[0]
+            except IndexError:
+                raise custom_exceptions.PubsubException("Not subscribed for event %s" % event)
+
+        else:
+            raise Exception("Searching subscriptions by key is not implemented yet")
+              
     @classmethod
     def iterate_subscribers(cls, event):
         for subscription in cls.__subscriptions.get(event, weakref.WeakKeyDictionary()).iterkeyrefs():
