@@ -97,8 +97,7 @@ def setup_finalize(event, application):
                                                            debug=settings.DEBUG,
                                                            signing_key=signing_key,
                                                            signing_id=settings.SIGNING_ID,
-                                                           event_handler=ServiceEventHandler,
-                                                           tcp_proxy_protocol_enable=settings.TCP_PROXY_PROTOCOL)
+                                                           event_handler=ServiceEventHandler)
         listenWS(ws)
     
     if settings.LISTEN_WSS_TRANSPORT and sslContext:  
@@ -117,4 +116,4 @@ def setup_finalize(event, application):
     return event
 
 if __name__ == '__main__':
-    print "This is not executable script. Try 'twistd -ny launcher.tac instead!"
\ No newline at end of file
+    print "This is not executable script. Try 'twistd -ny launcher.tac instead!"
